"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IsoDateTransformer = void 0;
const lodash_1 = require("lodash");
class IsoDateTransformer {
    static transform(target) {
        if (target instanceof Date) {
            return target;
        }
        const object = lodash_1.cloneDeep(target);
        if (this.isObject(object) && !this.isArray(object)) {
            for (const key in object) {
                const value = object[key];
                if (this.isObject(value)) {
                    object[key] = this.transform(value);
                }
                else {
                    if (this.isValidIsoString(value)) {
                        object[key] = new Date(value);
                    }
                }
            }
        }
        else {
            if (this.isArray(object) && !this.isString(object)) {
                for (let i = 0; i < object.length; i++) {
                    object[i] = this.transform(object[i]);
                }
            }
            if (this.isString(object)) {
                if (this.isValidIsoString(object)) {
                    return new Date(object);
                }
            }
        }
        return object;
    }
    // eslint-disable-next-line @typescript-eslint/ban-types
    static isObject(object) {
        return typeof object === 'object';
    }
    static isArray(object) {
        return object && object.length !== undefined;
    }
    static isString(object) {
        return typeof object === 'string';
    }
    static isValidIsoString(value) {
        const isoDateStringRegex = /\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+(?:[+-][0-2]\d:[0-5]\d|Z)/;
        if (typeof value === 'string') {
            const matchResult = value.match(isoDateStringRegex);
            return matchResult && matchResult.length === 1 && matchResult[0].length === value.length;
        }
        return false;
    }
}
exports.IsoDateTransformer = IsoDateTransformer;
